#
# spec file for package lxqt-session
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-session
Version:        2.1.0
Release:        1.1
Summary:        LXQt Session Manager
License:        LGPL-2.1-or-later
Group:          System/GUI/Other
URL:            https://github.com/lxqt/lxqt-session
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
# mvetter@suse.com bsc#1127043 - Use Openbox as default WM
Patch1:         %{name}-default_wm.patch
BuildRequires:  cmake >= 3.18.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  qtxdg-tools >= 4.1.0
BuildRequires:  xdg-user-dirs
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(LayerShellQt) >= 6.0.0
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(lxqt2-build-tools)
BuildRequires:  cmake(qtxdg-tools)
BuildRequires:  pkgconfig(libproc2) >= 4.0.0
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(lxqt) >= 2.1.0
BuildRequires:  pkgconfig(x11)
Requires(post): update-alternatives
Requires(postun):update-alternatives
Requires:       %{name}-branding = %{version}-%{release}
Requires:       qtxdg-tools
Recommends:     %{name}-lang = %{version}-%{release}

%description
lxqt-session is the standard session manager used by LXQt. The lxqt-session manager
is used to automatically start a set of applications and set up a working desktop
environment. Moreover, the session manager is able to remember the applications in
use when a user logs out and to restart them the next time the user logs in.

%lang_package

%package branding-upstream
Summary:        Upstream branding of %{name}
Group:          System/GUI/LXQt
Requires:       %{name} = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for %{name}.

%prep
%autosetup -p1
sed -i 's/^\(Type=\).*/\1XSession/' xsession/lxqt.desktop.in
sed -i '/^Categories/s/\(LXQt\;\)/X-\1/' lxqt-config-session/lxqt-config-session.desktop.in

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}
%fdupes -s %{buildroot}%{_datadir}
install -Dm 0644 %{buildroot}%{_datadir}/lxqt/{lxqt,session,windowmanagers,waylandwindowmanagers}.conf -t %{buildroot}%{_sysconfdir}/xdg/lxqt/

# for default-xsession
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

%find_lang %{name} --with-qt --all-name

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/lxqt.desktop 20

%postun
[ -f %{_datadir}/xsessions/lxqt.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/lxqt.desktop

%files
%license LICENSE
%doc AUTHORS CHANGELOG README.md
%{_bindir}/lxqt-config-session
%{_bindir}/%{name}
%{_bindir}/lxqt-leave
%{_datadir}/applications/lxqt-*.desktop
%{_mandir}/man?/lxqt-*%{?ext_man}
%config %{_sysconfdir}/xdg/autostart/lxqt-xscreensaver-autostart.desktop
%{_bindir}/startlxqt
%{_mandir}/man1/startlxqt.1%{?ext_man}
%{_datadir}/xsessions/lxqt.desktop
%{_datadir}/lxqt/lxqt.conf
%{_datadir}/lxqt/session.conf
%{_datadir}/lxqt/windowmanagers.conf
%{_datadir}/lxqt/waylandwindowmanagers.conf

# for default-xsession
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%ghost %{_sysconfdir}/alternatives/default.desktop
%{_datadir}/xsessions/default.desktop

%files branding-upstream
%dir %{_sysconfdir}/xdg/
%dir %{_sysconfdir}/xdg/lxqt/
%config %{_sysconfdir}/xdg/lxqt/lxqt.conf
%config %{_sysconfdir}/xdg/lxqt/session.conf
%config %{_sysconfdir}/xdg/lxqt/windowmanagers.conf
%config %{_sysconfdir}/xdg/lxqt/waylandwindowmanagers.conf

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%dir %{_datadir}/lxqt/translations/lxqt-config-session
%dir %{_datadir}/lxqt/translations/lxqt-leave
%dir %{_datadir}/lxqt/translations/%{name}

%changelog
* Mon Nov 11 2024 Shawn Dunn <sfalken@opensuse.org>
- Removed:
  * lxqt-0.13.0-xdg-config-dir.patch
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#556)
  * Weblate commits (#558)
  * Updated *.ts files (#557)
  * Weblate commits (#555)
  * GUI for custom screenlocker on x11 (#517)
  * Weblate commits (#553)
  * Updated Luganda (#552)
  * Weblate commits (#550)
  * Added scope=dialog to leave window (#551)
  * Weblate commits (#549)
* Sat May 11 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6.
  * Used an overlay layer shell for the leaving dialog and centered
    it under Wayland.
  * Made the user inputs stricter in auto-start.
  * Don't allow inputs consisting of only whitespaces, and remove
    start and end whitespaces from them.
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Update the DBus activation environment, to fix problems with
    apps (like Telegram) which set DBusActivatable to true in their
    desktop entries.
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Added support for procps-ng >= 4.0.0
  * Used a timer based checking for window manager and tray.
  * Disabled all crashing calls on Wayland.
  * Fixed typos
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Fixed the core code when lxqt-session is started under Wayland.
  * Reload mouse & touchpad settings when devices are reconnected.
* Mon May  9 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.1:
  * qtxdg-tools is added as a dependency, to be used by xdg-utils
    under LXQt Session (in near future).
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Added a simple option for global screen scaling.
  * Set Clearlooks as the default LXQt theme and changed the default
    icon theme to Breeze.
  * Add NetBSD support.
  * Prevented cut text in the header of Environment page of LXQt
    Session Settings.
- Remove lxqt-session-icontheme.patch:
  Upstream is using breeze now by default.
  Patch was added for bsc#1112961 bsc#1159958
* Sat Apr  2 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.0.1:
  * Restart failed modules with exit codes other than 0
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Bumped minimum required Qt version to 5.15 and updated translations.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Terminate all child processes on exiting the session.
  * Removed Openbox configuration.
  * Code cleanup and modernization.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Don't use deprecated QProcess methods.
  * Don't use 0/nullptr to initialize QFlags.
  * Removed Default Applications page.
* Mon Jun 29 2020 Michael Vetter <mvetter@suse.com>
- Dont BuildRequire Openbox and add %%dir %%{_sysconfdir}/xdg/openbox
  again. Openbox is not a hard requirement and thus might not
  be in dependency chain. The directory will then not be owned by
  any package once it is instaled.
* Wed Jun 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Don't package filesystem dirs
- BuildRequires openbox to provide /etc/xdg/openbox
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-session.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Fixed memory leak triggered by wine and specific games.
  * Corrected dialog location with multi-screen setups.
* Fri Feb  7 2020 Michael Vetter <mvetter@suse.com>
- bsc#1159958: Use breeze icon theme
  Paper doesn't have yast icons yet.
- Rename lxqt-session-papericontheme.patch to
  lxqt-session-icontheme.patch
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Fix build
- Add buildrequire for glib
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Wed Feb 27 2019 mvetter@suse.com
- bsc#1127043: Use Openbox as default WM
  0.14.0 removed Openbox as default WM from session config.
  At the same time if more than one WM is present at first start,
  a WM chooser dialog is shown. We want Openbox to stay the default
  WM even though we have it only as Recommends.
- Add lxqt-session-default_wm.patch
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Completed our WM list
  * Don’t default on Openbox, make the automatic WM
    selection more reliable
- Move translation from lxqt-l10n into package
* Tue Oct 23 2018 mvetter@suse.com
- bsc#1112961: Use Paper icon theme
  It gets installed through a Requires in patterns-lxqt
- Add lxqt-session-papericontheme.patch
* Tue Jul 24 2018 mvetter@suse.com
- bsc#1099800: Various LXQt components weren't able to find
  their config files
- Add lxqt-0.13.0-xdg-config-dir.patch
* Wed Jun 20 2018 mvetter@suse.com
- Obsolete lxqt-l10n: its not needed for 0.13.0
  All packages now contain the translations themselves
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Better support for *BSD world by changed usage of libudev
  * Use more directories for searching defaults (add /usr/share & /etc into XDG_CONFIG_DIRS)
* Tue May  8 2018 fabian@ritter-vogt.de
- Don't use %%fdupes -s as symlinks in the xsession directory have a
  special meaning (boo#1092251)
* Wed Oct 25 2017 mvetter@suse.com
- Add default-xsession which fvogt@suse.com added to
  (now deprecated) lxqt-common in the past
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * lxqt-session: Unify arguments parsing
  * Don't export github templates
  * Add/Update Lithuanian language
  * c'n'p bug
  * add basic cli to lxqt-session
  * lxqt-session: Provide reboot/powerOff methods
  * Drops Qt5Core_VERSION_STRING
  * lxqt-config-session: set Qt::AA_UseHighDpiPixmaps to true
  * lxqt-leave: set Qt::AA_UseHighDpiPixmaps to true
  * improved --version
  * Added QCommandLineParser and basic cli interface to lxqt-conf-session
  * Added default CMAKE_BUILD_TYPE and LXQT_SESSION_PATCH_VERSION
  * String encoding (#103)
  * Fixes a FTBFS in superbuild mode (#102)
  * lxqt-leave: Fix "disabled items" key navigation
  * Address "unused parameter" compiler warnings
  * lxqt-leave: Redesign dialog for good key navigation
  * Removed superfluous include(LXQtTranslateDesktop)
  * fixed config/CMakeLists.txt
  * Merged relevant parts of CMakeLists.txt.lxqt-common into CMakeLists.txt
  * Rename CMakeLists.txt -> CMakeLists.txt.lxqt-common
  * Add Basque translation of lxqt-leave and update Basque translation of lxqt-config-session
  * leavedialog: Use "expected" tab order
  * LeaveDialog: Accept enter key for action/cancel firing
  * LeaveDialog: Use "override" keyword
  * leavedialog: Don't trigger "cancel" on Enter
  * LeaveDialog: Use correct method
  * startlxqt: Consider $XDG_RUNTIME_DIR/bus for DBus
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Bump year
  * Update desktop entries and Replace fr_FR by fr
  * Use the LXQtConfigVars module
  * Fixed typo
  * Remove cpack (#61)
  * startlxqt: Consider LXQT_DEFAULT_OPENBOX_CONFIG
  * startlxqt: Honor the pre-defined SAL_USE_VLCPLUGIN
  * Replace lxqt-rc.xml with latest openbox version
  * startlxqt: Consider pre-exising LXDE OB config also
  * build: Revert @6d6d2bef54
  * build: Add xmessage as "dependency"
  * Openbox: Fix informational message about adoption of rc.xml
  * lxqt-rc.xml: Change default config install path
  * startlxqt: Copy existing openbox config preferably
  * Improves changed Openbox default path startup message (#51)
  * Disable gtk+ 3 overlay scrollbars by default.
  * Don't add XDG_DATA_HOME to XDG_DATA_DIRS (#47)
  * Message about Openbox default path changed.
  * Warning message about openbox settings path changed.
  * startlxqt: Force XDG_CONFIG_DIRS to contain @LXQT_ETC_XDG_DIR@
  * Copy openbox defaults at session start.
  * Rename openbox/rc.xml to openbox/lxqt-openbox-rc.xml
  * Openbox aero snap using mouse wheel over title bar.
  * Settings Openbox updated.
  * Default key shortcuts added to lxqt-globalkeysd.
  * CMakeLists: Use LXQT_GRAPHICS_DIR for graphics
  * Add startlxqt man page
  * Fixes #807 – Add XDG_CACHE_HOME definition
  * startlxqt: optimization of XDG_DATA_DIRS
  * corrected indentation
  * startlxqt: Set proper prefix for XDG_DATA_DIRS
  * Update Greek translation (el) Remove country variant from language code
  * Rename LxQt to LXQt everywhere
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Removes no added value comments
  * Adds double quotes to everything that may break
  * Use GNUINnstallDirs
  * Updates the build system to use the Targets infrastructure
  * Enable the "leave confirmation dialog" by default
  * TryExec to detect proper installed lxqt-session
  * Uniforms indentation
  * Sets env variable XDG_CONFIG_DIRS
  * Drops hardcoded /etc/xdg paths
  * Set LibreOffice's plugin env var to kde4
  * config: auto-detect succesfully kwin on recent kwin versions
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Adds an scalable start-here-lxqt icon
  * use LXQt-specific menu file
  * Renames some .desktop files
  * Portuguese update for .desktop files
  * - Unify naming for a unique lxqt. No more suffixes
  * Make frost the default theme
  * Defines XDG_DATA_HOME and XDG_DATA_DIRS environment variables
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * Clean up CMakeLists.txt and drop Qt 4 support
  * Set environment variable GTK_CSD=0 to turn off the default client side decoration for gtk+ 3 programs. (This will not always work if a gtk+3 program explicitly sets a title bar and turns on CSD.)
  * Add some more default values for Qt settings.
  * Update default config file.
  * Add Qt5 support.
  * Support Qt5 platform plugin and add some more comments.
  * Remove XDG_CURRENT_DESKTOP=Razor from environment variables.
  * Set XDG_CURRENT_DESKTOP to LXQt
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Use LXQt as desktop name
  * Add CPack rules for creating tarball
  * Add session.conf and windowmanagers.conf.
  * Change XDG_CURRENT_DESKTOP to Razor for now. (May rename to LxQt or something else in the future.)
  * Export environment varialbe QT_PLATFORM_PLUGIN=lxqt to let all Qt programs load lxqt-qtplugin and apply lxqt settings.
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Run lxde-qt with XDG_CURRENT_DESKTOP=RAZOR
  * Fix renaming bugs, replacing lxqt-qt with lxde-qt
  * Finish the crazy razor=>lxqt renaming tasks.
  * Rename dirs and replace razor with lxqt. Install lxqt.conf to /etc/xdg/lxqt and provide theme config.
  * Properly set default wallpaper for pcmanfm-qt. Comment out openbox config handling in startlxde-qt since it's not needed.
  * Remove custom openbox config file in desktop.conf temporarily until lxsession is fixed.
  * Fix file paths, replacing razor with lxqt. * Remove Alt+F2 and Ctrl+Esc from openbox config file to avoid conflicts with lxqt-panel & lxqt-globalkeys.
  * Add default configuration files for lxde-qt session.
- Remove because contained in new release:
  * lxqt-session-0.11.1-add-poweroff.patch
  * lxqt-session-0.11.1-string-encoding.patch
* Wed Sep 13 2017 mvetter@suse.com
- boo#1044483:
  * Add lxqt-session-0.11.1-string-encoding.patch
    to have new string encoding
  * Add lxqt-session-0.11.1-add-poweroff.patch
    add option to power off
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Adds an nullptr check when restarting a module (#90)
  * Fixes a session logout crash (#88)
  * Updated da.desktop files and removed da_DK.desktop files
  * Moves FindUDev to the lxqt-build-tools repo
  * Reworks X11 CMake libraries
  * Removes all XCB stuff from CMake
  * Update french desktop entries
  * lxqt-config-session: Use localized comment
  * Make CMakeLists.txt more uniform.
  * Remove cpack (#83)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * lockscreenmanager: always listen to the session provider's lock signal (#79)
  * Update Polish translation
  * Add README.md
  * lxqt-config-session: Warn about restart required when removing env variable
  * Add Catalan translations
  * lockscreenmanager: use categorized logger
  * Make screen locking before power actions optional
  * Add and Update Arabic Translations for Desktop Files
  * lxqt-session: Replace qCInfo() by qCWarning()
  * Adds an WITH_LIBUDEV CMake option (#74)
  * lockscreenmanager: add more log messages
  * Add logic to lock screen before system sleeps
  * lxqt-session: Use QLoggingCategory for logging/debug
  * lxqt-session: Use the base name to compare Wm's names
  * build: Use external translations
  * ts-files removal (#72)
  * Use const references with the foreach iterator
  * leave: ask or not for confirmation from main dialog
  * Adjust config dialog's size on startup
  * Make it compile using QT_USE_QSTRINGBUILDER
  * Fix lxqt-leave tab order
  * lxqt-session doesn't copy openbox defaults at session start. startlxqt from lxqt-common will copy it.
  * fixup...centering & spacing
  * leave: do not set maximum size as minimum size
  * Use XdgDir to find default path.
  * Openbox default settings removed.
  * Load LXQt default settings for Openbox.
  * UserLocations: An user entered empty string represents the default value
  * lxqt-config-session: Adds tooltips to the User Directories edits
  * lxqt-config-session: Replaces Locations by User Directories
  * Bump year Fix used licenses. lxqt-session is LGPL only
  * Re-arrange the buttons
  * lxqt-leave: Reworks window flags
  * lxqt-leave: Make all buttons of equal width
  * lxqt-leave: Center the dialog relative to the screen
  * lxqt-leave: Removes window border and makes it stay on top
  * lxqt-leave: Make the icons bigger and improves button alignement
  * Updated german translation.
  * Fix realloc() usage Check malloc() call result against NULL
  * Add HR translations
  * lxqt-session: Update man pages and make session the overview
  * Update italian translation
  * Updated Russian translations Removed ru_RU files
  * Makes the dependency on xdg-user-dirs-update explicit
  * Fix ending session and stopping modules
  * upd: lxqt-config-session_hu.ts del: lxt-config-session_hu_HU.ts
  * Fix desktop file
  * Make desktop files valid
  * CMakeLists.txt: Add cmake minimum required version
- Add keyring
- Remove 0001-Make-desktop-files-valid.patch: upstreamed
- Remove 0002-Fix-desktop-file.patch: upstreamed
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
- Adding patches to make desktop files valid:
  * 0001-Make-desktop-files-valid.patch
  * 0002-Fix-desktop-file.patch
- Removing patches:
  * fix_desktop_categories.patch - Using sed in spec file now.
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to used cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Added Patch
  + fix_desktop_categories.patch - fixes category definitions to
  comply with openSUSE policy
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 sfalken@opensuse.org
- Specfile Cleanup
* Mon May 12 2014 sfalken@opensuse.org
-  Removed fedora specfile, split into subproject
  Del: lxqt-session-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-session-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-session-0.7.0.tar.xz
  Del:  _service
* Thu Apr  3 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-session.spec
  Add: lxqt-session.changes
